from nocasedict import NoCaseDict
from regexpdict import RegexpDict
from sorteddict import *
from dict import Dict

__author__ = "Miguel Olivares"
__email__ = "miguel@moliware.com"
__version__ = '0.3.1'


# -*- coding: utf-8 -*-
"""
    dict.sorteddict
    ~~~~~~~~~~~~~~~

    Dictionaries that are sorted when they are iterated

    :copyright: (c) 2011 by  Miguel Olivares <miguel@moliware.com>.
    :license: LGPL, see LICENSE for more details.
"""
from dict import Dict


class SortedDict(Dict):
    """ Dictionary that iterates over its elements. """

    def __init__(self, data={}, cmp=None, key=None, reverse=False):
        """
        :param data: dictionary
        :param cmp: comparison function
        :param key: function to extract comparison key
        :param reverse: reverse order
        """
        super(SortedDict, self).__init__(data)
        self.cmp = cmp
        self.key = key
        self.reverse= reverse

    def __iter__(self):
        return self.iterkeys()
        
    def __getslice__(self, i, j):
        return type(self)(self.items()[i:j])

    def iteritems(self):
        """ Sort and then iterate the dictionary """
        sorted_data = sorted(self.data.iteritems(), self.cmp, self.key,
                             self.reverse)
        for k,v in sorted_data:
            yield k,v


    def items(self):
        return [x for x in self.iteritems()]

    def iterkeys(self):
        for k,v in self.iteritems():
            yield k

    def keys(self):
        return [k for k in self.iterkeys()]

    def itervalues(self):
        for k,v in self.iteritems():
            yield v

    def values(self):
        return [v for v in self.itervalues()]


class KeySortedDict(SortedDict):
    """ Dictionary sorted by key """

    def __init__(self, data={}, reverse=False):
        """
        :param data: dictionary
        :param reverse: reverse order
        """
        super(KeySortedDict, self).__init__(data, reverse=reverse)


class ValueSortedDict(SortedDict):
    """ Dictionary sorted by value """

    def __init__(self, data={}, reverse=False):
        """
        :param data: dictionary
        :param reverse: reverse order
        """
        super(ValueSortedDict, self).__init__(data, key=lambda x:x[1],
                                               reverse=reverse)


# -*- coding: utf-8 -*-
from distutils.core import setup

import dicts

setup(name = 'dicts',
      version = dicts.__version__,
      description = 'Easy use dictionaries with specific features',
      long_description = open('README.rst').read(),
      author = dicts.__author__,
      author_email = dicts.__email__,
      url = 'https://github.com/moliware/dicts',
      packages = ['dicts'],
      license = 'LGPL',
      classifiers = ('Development Status :: 5 - Production/Stable',
                     'License :: OSI Approved :: GNU Library or Lesser General Public License (LGPL)',
                     'Natural Language :: English',
                     'Programming Language :: Python :: 2.5',
                     'Programming Language :: Python :: 2.6',
                     'Programming Language :: Python :: 2.7',
      ),
)



# -*- coding: utf-8 -*-


import unittest
from dicts import RegexpDict


class RegexpDictTestCase(unittest.TestCase):
    """ Dict features test cases."""

    def setUp(self):
        self.d = RegexpDict({'\d+' : 1, '\w+': 2})

    def tearDown(self):
        pass

    def test_getitem(self):
        self.assertEquals(self.d['1'], [1, 2])
        self.assertEquals(self.d['abc'], [2])

if __name__ == '__main__':
    unittest.main()